pub fn ripemd160_run(input: &[u8], gas_limit: u64) -> EthPrecompileResultExpand description
Computes the RIPEMD-160 hash of the input data
This function follows specifications defined in the following references:
pub fn ripemd160_run(input: &[u8], gas_limit: u64) -> EthPrecompileResultComputes the RIPEMD-160 hash of the input data
This function follows specifications defined in the following references: