pub enum PrecompileError {
Show 38 variants
OutOfGas,
Blake2WrongLength,
Blake2WrongFinalIndicatorFlag,
ModexpExpOverflow,
ModexpBaseOverflow,
ModexpModOverflow,
ModexpEip7823LimitSize,
Bn254FieldPointNotAMember,
Bn254AffineGFailedToCreate,
Bn254PairLength,
BlobInvalidInputLength,
BlobMismatchedVersion,
BlobVerifyKzgProofFailed,
NonCanonicalFp,
Bls12381G1NotOnCurve,
Bls12381G1NotInSubgroup,
Bls12381G2NotOnCurve,
Bls12381G2NotInSubgroup,
Bls12381ScalarInputLength,
Bls12381G1AddInputLength,
Bls12381G1MsmInputLength,
Bls12381G2AddInputLength,
Bls12381G2MsmInputLength,
Bls12381PairingInputLength,
Bls12381MapFpToG1InputLength,
Bls12381MapFp2ToG2InputLength,
Bls12381FpPaddingInvalid,
Bls12381FpPaddingLength,
Bls12381G1PaddingLength,
Bls12381G2PaddingLength,
KzgInvalidG1Point,
KzgG1PointNotOnCurve,
KzgG1PointNotInSubgroup,
KzgInvalidInputLength,
Secp256k1RecoverFailed,
Fatal(String),
FatalAny(AnyError),
Other(Cow<'static, str>),
}Expand description
Precompile error type.
Variants
OutOfGas
out of gas is the main error. Others are here just for completeness
Blake2WrongLength
Blake2 errors
Blake2WrongFinalIndicatorFlag
Blake2 wrong final indicator flag
ModexpExpOverflow
Modexp errors
ModexpBaseOverflow
Modexp base overflow
ModexpModOverflow
Modexp mod overflow
ModexpEip7823LimitSize
Modexp limit all input sizes.
Bn254FieldPointNotAMember
Bn254 errors
Bn254AffineGFailedToCreate
Bn254 affine g failed to create
Bn254PairLength
Bn254 pair length
BlobInvalidInputLength
The input length is not exactly 192 bytes
BlobMismatchedVersion
The commitment does not match the versioned hash
BlobVerifyKzgProofFailed
The proof verification failed
NonCanonicalFp
Non-canonical field element
Bls12381G1NotOnCurve
BLS12-381 G1 point not on curve
Bls12381G1NotInSubgroup
BLS12-381 G1 point not in correct subgroup
Bls12381G2NotOnCurve
BLS12-381 G2 point not on curve
Bls12381G2NotInSubgroup
BLS12-381 G2 point not in correct subgroup
Bls12381ScalarInputLength
BLS12-381 scalar input length error
Bls12381G1AddInputLength
BLS12-381 G1 add input length error
Bls12381G1MsmInputLength
BLS12-381 G1 msm input length error
Bls12381G2AddInputLength
BLS12-381 G2 add input length error
Bls12381G2MsmInputLength
BLS12-381 G2 msm input length error
Bls12381PairingInputLength
BLS12-381 pairing input length error
Bls12381MapFpToG1InputLength
BLS12-381 map fp to g1 input length error
Bls12381MapFp2ToG2InputLength
BLS12-381 map fp2 to g2 input length error
Bls12381FpPaddingInvalid
BLS12-381 padding error
Bls12381FpPaddingLength
BLS12-381 fp padding length error
Bls12381G1PaddingLength
BLS12-381 g1 padding length error
Bls12381G2PaddingLength
BLS12-381 g2 padding length error
KzgInvalidG1Point
KZG invalid G1 point
KzgG1PointNotOnCurve
KZG G1 point not on curve
KzgG1PointNotInSubgroup
KZG G1 point not in correct subgroup
KzgInvalidInputLength
KZG input length error
Secp256k1RecoverFailed
secp256k1 ecrecover failed
Fatal(String)
Unrecoverable error that halts EVM execution.
Unlike other variants which result in a normal precompile revert,
this error propagates as EVMError::Custom and aborts the entire transaction.
FatalAny(AnyError)
Unrecoverable error that halts EVM execution.
Unlike other variants which result in a normal precompile revert,
this error propagates as EVMError::Custom and aborts the entire transaction.
Other(Cow<'static, str>)
Catch-all variant for precompile errors without a dedicated variant.
This is handled like any other named error variant (e.g. OutOfGas, Blake2WrongLength)
and results in a normal precompile revert, not a fatal EVM error.
Implementations
Sourceimpl PrecompileError
impl PrecompileError
Sourcepub const fn other_static(err: &'static str) -> Self
pub const fn other_static(err: &'static str) -> Self
Returns another error with the given static string.