pub enum PrecompileStatus {
Success,
Revert,
Halt(PrecompileHalt),
}Expand description
Status of a precompile execution.
Variants
Success
Precompile executed successfully.
Revert
Precompile reverted (non-fatal, returns remaining gas).
Halt(PrecompileHalt)
Precompile halted with a specific reason.
Implementations
Sourceimpl PrecompileStatus
impl PrecompileStatus
Sourcepub fn is_success_or_revert(&self) -> bool
pub fn is_success_or_revert(&self) -> bool
Returns true if the precompile execution was successful or reverted.
Sourcepub fn is_revert_or_halt(&self) -> bool
pub fn is_revert_or_halt(&self) -> bool
Returns true if the precompile execution was reverted or halted.
Sourcepub fn halt_reason(&self) -> Option<&PrecompileHalt>
pub fn halt_reason(&self) -> Option<&PrecompileHalt>
Returns the halt reason if the precompile halted, None otherwise.
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if the precompile execution was successful.