pub struct PrecompileOutput {
pub status: PrecompileStatus,
pub gas_used: u64,
pub gas_refunded: i64,
pub state_gas_used: u64,
pub reservoir: u64,
pub bytes: Bytes,
}Expand description
Rich precompile execution output with gas accounting and status support.
This is the output type used at the precompile provider level. It can express successful execution, reverts, and halts (non-fatal errors like out-of-gas).
Fields
status: PrecompileStatusStatus of the precompile execution.
gas_used: u64Regular gas used by the precompile.
gas_refunded: i64Gas refunded by the precompile.
state_gas_used: u64State gas used by the precompile.
reservoir: u64Reservoir gas for EIP-8037.
bytes: BytesOutput bytes.
Implementations
Sourceimpl PrecompileOutput
impl PrecompileOutput
Sourcepub fn from_eth_result(result: EthPrecompileResult, reservoir: u64) -> Self
pub fn from_eth_result(result: EthPrecompileResult, reservoir: u64) -> Self
Returns a new precompile output from an Ethereum precompile result.
Sourcepub const fn new(gas_used: u64, bytes: Bytes, reservoir: u64) -> Self
pub const fn new(gas_used: u64, bytes: Bytes, reservoir: u64) -> Self
Returns a new successful precompile output.
Sourcepub const fn halt(reason: PrecompileHalt, reservoir: u64) -> Self
pub const fn halt(reason: PrecompileHalt, reservoir: u64) -> Self
Returns a new halted precompile output with the given halt reason.
Sourcepub const fn revert(gas_used: u64, bytes: Bytes, reservoir: u64) -> Self
pub const fn revert(gas_used: u64, bytes: Bytes, reservoir: u64) -> Self
Returns a new reverted precompile output.
Sourcepub const fn is_success(&self) -> bool
pub const fn is_success(&self) -> bool
Returns true if the precompile execution was successful.
Sourcepub const fn is_ok(&self) -> bool
👎Deprecated: use is_success instead
pub const fn is_ok(&self) -> bool
use is_success instead
Returns true if the precompile execution was successful.
Sourcepub const fn halt_reason(&self) -> Option<&PrecompileHalt>
pub const fn halt_reason(&self) -> Option<&PrecompileHalt>
Returns the halt reason if the precompile halted, None otherwise.