PrecompileEthFn

Type Alias PrecompileEthFn 

pub type PrecompileEthFn = fn(&[u8], u64) -> EthPrecompileResult;
Eth precompile function type. Takes input and gas limit, returns an Eth precompile result.

This is the function signature used by individual Ethereum precompile implementations. Use PrecompileFn for the higher-level type that returns PrecompileOutput.